indicatortools.Annotation
=========================

.. abjad-lineage:: abjad.tools.indicatortools.Annotation.Annotation

.. autoclass:: abjad.tools.indicatortools.Annotation.Annotation

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.Annotation.Annotation.name
      ~abjad.tools.indicatortools.Annotation.Annotation.value
      ~abjad.tools.indicatortools.Annotation.Annotation.__copy__
      ~abjad.tools.indicatortools.Annotation.Annotation.__eq__
      ~abjad.tools.indicatortools.Annotation.Annotation.__format__
      ~abjad.tools.indicatortools.Annotation.Annotation.__ne__
      ~abjad.tools.indicatortools.Annotation.Annotation.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.Annotation.Annotation.name
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.Annotation.Annotation.value
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.Annotation.Annotation.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Annotation.Annotation.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Annotation.Annotation.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Annotation.Annotation.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Annotation.Annotation.__repr__
   :noindex:
